@@ -20,7 +20,7 @@ from . import constants
 
 DEFAULT_CONNECT_TIMEOUT_SECS: float = 5.0
 DEFAULT_TIMEOUT_SECS: float = 30.0
-DEFAULT_WAIT_FOR_TRANSACTION_TIMEOUT_SECS: float = 5.0
+DEFAULT_WAIT_FOR_TRANSACTION_TIMEOUT_SECS: float = 30.0
 DEFAULT_WAIT_FOR_TRANSACTION_WAIT_DURATION_SECS: float = 0.2
 
 
@@ -420,7 +420,7 @@ class Client:
         """
 
         if isinstance(txn, diem_types.SignedTransaction):
-            return self.submit(txn.lcs_serialize().hex())
+            return self.submit(txn.bcs_serialize().hex())
 
         self.execute_without_retry("submit", [txn], result_parser=None, ignore_stale_response=not raise_stale_response)
 
@@ -444,7 +444,7 @@ class Client:
         """
 
         if isinstance(txn, str):
-            txn_obj = diem_types.SignedTransaction.lcs_deserialize(bytes.fromhex(txn))
+            txn_obj = diem_types.SignedTransaction.bcs_deserialize(bytes.fromhex(txn))
             return self.wait_for_transaction(txn_obj, timeout_secs)
 
         return self.wait_for_transaction2(
